Learn R Programming

popPCR (version 0.1.1.1)

calculateConc: Target copies estimation

Description

Mean target copies per partition (lambda) is derived using Poisson distribution as lambda = -ln(nneg / ntot). Target copies in sample is then calculated as conc = lambda * volSamp/(volDrp * 1000).

Usage

calculateConc(nneg, ntotal, volSamp, volDrp)

Arguments

nneg

numeric, negative droplet count

ntotal

numeric, total droplet count

volSamp

numeric, sample volume in microliter

volDrp

numeric, droplet (or partition) volume in nanoliter

Value

Returns a list with 2 named items lambda and conc

  • lambda - numeric, vector of mean target copies per partition (lambda) and its lower and upper 95% confidence interval

  • conc - numeric, vector of target copies in sample (based on the given sample volume (volSamp) and droplet volume (volDrp)) and its lower and upper 95% confidence interval

Examples

Run this code
# NOT RUN {
estimates <- calculateConc(5000, 20000, volSamp = 20, volDrp = 0.85)
estimates
#    Output:
#       $lambda
#          lambda     lower      upper
#       1.386294   1.362289   1.410299
#
#       $conc
#           conc      lower      upper
#       32618.69   32053.87   33183.51
# }

Run the code above in your browser using DataLab